ete2.treeview._about

Package ete2 :: Package treeview :: Module _about |
[hide private]
[frames] | no frames]

# Source Code for Module ete2.treeview._about

     1  # #START_LICENSE###########################################################
     2  #
     3  # Copyright (C) 2009 by Jaime Huerta Cepas. All rights reserved.
     4  # email: jhcepas@gmail.com
     5  #
     6  # This file is part of the Environment for Tree Exploration program (ETE).
     7  # http://ete.cgenomics.org
     8  #
     9  # ETE is free software: you can redistribute it and/or modify it
    10  # under the terms of the GNU General Public License as published by
    11  # the Free Software Foundation, either version 3 of the License, or
    12  # (at your option) any later version.
    13  #
    14  # ETE is distributed in the hope that it will be useful,
    15  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    16  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    17  # GNU General Public License for more details.
    18  #
    19  # You should have received a copy of the GNU General Public License
    20  # along with ETE.  If not, see <http://www.gnu.org/licenses/>.
    21  #
    22  # #END_LICENSE#############################################################
    23  __VERSION__="ete2-2.0rev90"
    24  # -*- coding: utf-8 -*-
    25
    26  # Form implementation generated from reading ui file 'about.ui'
    27  #
    28  # Created: Wed Sep  2 16:54:14 2009
    29  #      by: PyQt4 UI code generator 4.5.4
    30  #
    31  # WARNING! All changes made in this file will be lost!
    32
    33  try:
    34      from PyQt4 import QtCore, QtGui
    35  except ImportError:
    36      import QtCore, QtGui
    37
    38 -class Ui_About(object):
    39 -    def setupUi(self, About):
    40          About.setObjectName("About")
    41          About.resize(462, 249)
    42          self.verticalLayoutWidget = QtGui.QWidget(About)
    43          self.verticalLayoutWidget.setGeometry(QtCore.QRect(10, 0, 441, 208))
    44          self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
    45          self.verticalLayout = QtGui.QVBoxLayout(self.verticalLayoutWidget)
    46          self.verticalLayout.setObjectName("verticalLayout")
    47          self.label = QtGui.QLabel(self.verticalLayoutWidget)
    48          self.label.setObjectName("label")
    49          self.verticalLayout.addWidget(self.label)
    50          self.version = QtGui.QLabel(self.verticalLayoutWidget)
    51          self.version.setObjectName("version")
    52          self.verticalLayout.addWidget(self.version)
    53
    54          self.retranslateUi(About)
    55          QtCore.QMetaObject.connectSlotsByName(About)
    56
    57 -    def retranslateUi(self, About):
    58          About.setWindowTitle(QtGui.QApplication.translate("About", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
    59          self.label.setText(QtGui.QApplication.translate("About", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
    60  "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
    61  "p, li { white-space: pre-wrap; }\n"
    62  "</style></head><body style=\" font-family:\'DejaVu Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
    63  "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><img src=\":/ete icons/ete_logo.png\" /></p>\n"
    64  "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-weight:600;\"><span style=\" font-size:11pt;\">ETE: a python Environment for Tree Exploration</span></p>\n"
    65  "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:11pt; font-weight:600;\"><a href=\"http://ete.cgenomics.org\"><span style=\" text-decoration: underline; color:#0057ae;\">http://ete.cgenomics.org</span></a></p>\n"
    66  "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-weight:600;\">Copyright (C) 2008-2009 </p>\n"
    67  "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-weight:600;\"><span style=\" font-weight:400;\">Created by Jaime Huerta-Cepas</span></p>\n"
    68  "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">jhcepas@crg.es</p>\n"
    69  "<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"></p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
    70          self.version.setText(QtGui.QApplication.translate("About", "VERSION", None, QtGui.QApplication.UnicodeUTF8))
    71
    72  import ete_resources_rc
    73